function x = round2n(x,n,opt)
%   Rounds input data at specified power of 10
%
%  Y = ROUND2N(X,N) rounds the input data X at the specified power of ten
%
%  Y = ROUND2N(X,N,OPT) returns Y as a char array if NUMEL(X) == 1
%  or in a cell array if X is a matrix
%
%   Examples:
%       round2n(pi,-3)                  -> numeric output
%       round2n(pi*100,1)               -> numeric output
%       round2n(rand(3)*pi,-2,'opt')    -> cell array output
%
%   Credits:
%       Based on roundn.m of the Mapping Toolbox
%
%   Joaquim Luis

if nargin < 2
    error('Incorrect number of arguments')
end

if (n - fix(n) ~= 0)
    disp(['N should have been an integer. Rounding to:' num2str(round(n))])
    n = round(n);
end

fact = 10 ^ (-n);
x = round(x * fact) / fact;

if (nargin == 3)                    % Output is a char or a cell array
    if (n < 0)
        frmt = ['%.' num2str(abs(n)) 'f'];
    else
        frmt = '%.0f';
    end
   
    if (numel(x) == 1)              % Output in a char array
        x = num2str(x,frmt);
    else                            % Output in a cell array
        out = cell(size(x));
        for (i = 1:numel(x))        % Maybe there is a vectorized option to do this
            out{i} = num2str(x(i),frmt);
        end
        x = out;
    end
end

